@@ -1,19 +1,28 @@
+import lxml.html as htmlparser
 import regex
 
 STREAMLARE = "https://streamlare.com/"
 
-CONTENT_ID = regex.compile(r"/e/([^?#&/]+)")
+CONTENT_ID = regex.compile(r"/[ve]/([^?#&/]+)")
 
 
 def extract(session, url, **opts):
 
+    csrf_token = (
+        htmlparser.fromstring(session.get(url).text)
+        .cssselect("meta[name='csrf-token']")[0]
+        .get("content")
+    )
     content_id = CONTENT_ID.search(url).group(1)
 
     def fast_yield():
         for _, streams in (
             session.post(
                 STREAMLARE + "api/video/get",
-                headers={"x-requested-with": "XMLHttpRequest"},
+                headers={
+                    "x-requested-with": "XMLHttpRequest",
+                    "x-csrf-token": csrf_token,
+                },
                 json={"id": content_id},
             )
             .json()
